==> cloudsnorkel.cdk-turbo-layers-0.0.1.tar.gz: package/assets/package-codebuild.lambda/index.js <==
"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/package-codebuild.lambda.ts
var package_codebuild_lambda_exports = {};
__export(package_codebuild_lambda_exports, {
  handler: () => handler
});
module.exports = __toCommonJS(package_codebuild_lambda_exports);
var AWS = __toESM(require("aws-sdk"));

// src/cr.ts
async function customResourceRespond(event, responseStatus, reason, physicalResourceId, data) {
  const responseBody = JSON.stringify({
    Status: responseStatus,
    Reason: reason,
    PhysicalResourceId: physicalResourceId,
    StackId: event.StackId,
    RequestId: event.RequestId,
    LogicalResourceId: event.LogicalResourceId,
    NoEcho: false,
    Data: data
  });
  console.log("Responding", responseBody);
  const parsedUrl = require("url").parse(event.ResponseURL);
  const requestOptions = {
    hostname: parsedUrl.hostname,
    path: parsedUrl.path,
    method: "PUT",
    headers: {
      "content-type": "",
      "content-length": responseBody.length
    }
  };
  return new Promise((resolve, reject) => {
    try {
      const request = require("https").request(requestOptions, resolve);
      request.on("error", reject);
      request.write(responseBody);
      request.end();
    } catch (e) {
      reject(e);
    }
  });
}

// src/package-codebuild.lambda.ts
var codebuild = new AWS.CodeBuild();
var s3 = new AWS.S3();
async function handler(event, context) {
  try {
    console.log(JSON.stringify({ ...event, ResponseURL: "..." }));
    const projectName = event.ResourceProperties.ProjectName;
    const installRuntimeCommands = event.ResourceProperties.CodeBuildInstallCommands;
    const preinstallCommands = event.ResourceProperties.PreinstallCommands;
    const commands = event.ResourceProperties.Commands;
    const packagedDirectory = event.ResourceProperties.PackagedDirectory;
    const assetBucket = event.ResourceProperties.AssetBucket;
    const assetKey = event.ResourceProperties.AssetKey;
    const targetBucket = event.ResourceProperties.BucketName;
    const failCheckCommands = [`if [ $CODEBUILD_BUILD_SUCCEEDING -ne 1 ]; then
cat <<EOF > /tmp/payload.json
{
  "StackId": "$STACK_ID",
  "RequestId": "$REQUEST_ID",
  "LogicalResourceId": "$LOGICAL_RESOURCE_ID",
  "PhysicalResourceId": "fail",
  "Status": "FAILED",
  "Reason": \`tail -c 400 /tmp/codebuild.log | jq -Rsa .\`,
  "Data": {}
}
EOF
  if [ "$RESPONSE_URL" != "unspecified" ]; then
    jq . /tmp/payload.json; curl -fsSL -X PUT -H "Content-Type:" -d "@/tmp/payload.json" "$RESPONSE_URL"
  fi
fi`];
    switch (event.RequestType) {
      case "Create":
      case "Update":
        console.log(`Starting CodeBuild project ${projectName}`);
        await codebuild.startBuild({
          projectName,
          sourceTypeOverride: "S3",
          sourceLocationOverride: `${assetBucket}/${assetKey}`,
          buildspecOverride: JSON.stringify({
            version: "0.2",
            env: {
              variables: {
                STACK_ID: event.StackId,
                REQUEST_ID: event.RequestId,
                LOGICAL_RESOURCE_ID: event.LogicalResourceId,
                RESPONSE_URL: event.ResponseURL
              }
            },
            phases: {
              install: {
                commands: logCommands(installRuntimeCommands),
                finally: failCheckCommands
              },
              pre_build: {
                commands: logCommands(preinstallCommands),
                finally: failCheckCommands
              },
              build: {
                commands: logCommands(
                  commands.concat([
                    // `find ${internalProps.targetDirectory} | xargs -L 100 touch -m -t 200001010101.01`, // consistent dates for consistent zips
                    `zip -r package.zip ${packagedDirectory}`,
                    'KEY=`sha256sum package.zip | cut -d " " -f 1`.zip',
                    `aws s3 cp --no-progress package.zip s3://${targetBucket}/\${KEY}`,
                    "echo -n $KEY > KEY"
                  ])
                )
              },
              post_build: {
                commands: [
                  'if [ $CODEBUILD_BUILD_SUCCEEDING -eq 1 ]; then\ncat <<EOF > /tmp/payload.json\n{\n  "StackId": "$STACK_ID",\n  "RequestId": "$REQUEST_ID",\n  "LogicalResourceId": "$LOGICAL_RESOURCE_ID",\n  "PhysicalResourceId": "`cat KEY`",\n  "Status": "SUCCESS",\n  "Reason": "",\n  "Data": {}\n}\nEOF\nif [ "$RESPONSE_URL" != "unspecified" ]; then\njq . /tmp/payload.json; curl -fsSL -X PUT -H "Content-Type:" -d "@/tmp/payload.json" "$RESPONSE_URL"\nfi\nfi'
                ],
                finally: failCheckCommands
              }
            }
          }, null, 2)
        }).promise();
        break;
      case "Delete":
        try {
          await s3.deleteObject({
            Bucket: targetBucket,
            Key: event.PhysicalResourceId
          }).promise();
        } catch (e) {
          console.error(`Ignoring error to delete s3://${targetBucket}/${event.PhysicalResourceId}`);
        }
        await customResourceRespond(event, "SUCCESS", "", event.PhysicalResourceId, {});
        break;
    }
  } catch (e) {
    console.error(e);
    await customResourceRespond(event, "FAILED", e.message || "Internal Error", context.logStreamName, {});
  }
}
function logCommands(commands) {
  return [["( set -ex"].concat(commands).concat([" ) 2>&1 | tee /tmp/codebuild.log"]).join(" ; ")];
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  handler
});

==> cloudsnorkel.cdk-turbo-layers-0.1.0.tar.gz: package/assets/package-codebuild.lambda/index.js <==
"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/package-codebuild.lambda.ts
var package_codebuild_lambda_exports = {};
__export(package_codebuild_lambda_exports, {
  handler: () => handler
});
module.exports = __toCommonJS(package_codebuild_lambda_exports);
var AWS = __toESM(require("aws-sdk"));

// src/cr.ts
async function customResourceRespond(event, responseStatus, reason, physicalResourceId, data) {
  const responseBody = JSON.stringify({
    Status: responseStatus,
    Reason: reason,
    PhysicalResourceId: physicalResourceId,
    StackId: event.StackId,
    RequestId: event.RequestId,
    LogicalResourceId: event.LogicalResourceId,
    NoEcho: false,
    Data: data
  });
  console.log("Responding", responseBody);
  const parsedUrl = require("url").parse(event.ResponseURL);
  const requestOptions = {
    hostname: parsedUrl.hostname,
    path: parsedUrl.path,
    method: "PUT",
    headers: {
      "content-type": "",
      "content-length": responseBody.length
    }
  };
  return new Promise((resolve, reject) => {
    try {
      const request = require("https").request(requestOptions, resolve);
      request.on("error", reject);
      request.write(responseBody);
      request.end();
    } catch (e) {
      reject(e);
    }
  });
}

// src/package-codebuild.lambda.ts
var codebuild = new AWS.CodeBuild();
var s3 = new AWS.S3();
async function handler(event, context) {
  try {
    console.log(JSON.stringify({ ...event, ResponseURL: "..." }));
    const projectName = event.ResourceProperties.ProjectName;
    const installRuntimeCommands = event.ResourceProperties.CodeBuildInstallCommands;
    const preinstallCommands = event.ResourceProperties.PreinstallCommands;
    const commands = event.ResourceProperties.Commands;
    const packagedDirectory = event.ResourceProperties.PackagedDirectory;
    const assetBucket = event.ResourceProperties.AssetBucket;
    const assetKey = event.ResourceProperties.AssetKey;
    const targetBucket = event.ResourceProperties.BucketName;
    const failCheckCommands = [`if [ $CODEBUILD_BUILD_SUCCEEDING -ne 1 ]; then
cat <<EOF > /tmp/payload.json
{
  "StackId": "$STACK_ID",
  "RequestId": "$REQUEST_ID",
  "LogicalResourceId": "$LOGICAL_RESOURCE_ID",
  "PhysicalResourceId": "fail",
  "Status": "FAILED",
  "Reason": \`tail -c 400 /tmp/codebuild.log | jq -Rsa .\`,
  "Data": {}
}
EOF
  if [ "$RESPONSE_URL" != "unspecified" ]; then
    jq . /tmp/payload.json; curl -fsSL -X PUT -H "Content-Type:" -d "@/tmp/payload.json" "$RESPONSE_URL"
  fi
fi`];
    switch (event.RequestType) {
      case "Create":
      case "Update":
        console.log(`Starting CodeBuild project ${projectName}`);
        await codebuild.startBuild({
          projectName,
          sourceTypeOverride: "S3",
          sourceLocationOverride: `${assetBucket}/${assetKey}`,
          buildspecOverride: JSON.stringify({
            version: "0.2",
            env: {
              variables: {
                STACK_ID: event.StackId,
                REQUEST_ID: event.RequestId,
                LOGICAL_RESOURCE_ID: event.LogicalResourceId,
                RESPONSE_URL: event.ResponseURL
              }
            },
            phases: {
              install: {
                commands: logCommands(installRuntimeCommands),
                finally: failCheckCommands
              },
              pre_build: {
                commands: logCommands(preinstallCommands),
                finally: failCheckCommands
              },
              build: {
                commands: logCommands(
                  commands.concat([
                    // `find ${internalProps.targetDirectory} | xargs -L 100 touch -m -t 200001010101.01`, // consistent dates for consistent zips
                    `zip -r package.zip ${packagedDirectory}`,
                    'KEY=`sha256sum package.zip | cut -d " " -f 1`.zip',
                    `aws s3 cp --no-progress package.zip s3://${targetBucket}/\${KEY}`,
                    "echo -n $KEY > KEY"
                  ])
                )
              },
              post_build: {
                commands: [
                  'if [ $CODEBUILD_BUILD_SUCCEEDING -eq 1 ]; then\ncat <<EOF > /tmp/payload.json\n{\n  "StackId": "$STACK_ID",\n  "RequestId": "$REQUEST_ID",\n  "LogicalResourceId": "$LOGICAL_RESOURCE_ID",\n  "PhysicalResourceId": "`cat KEY`",\n  "Status": "SUCCESS",\n  "Reason": "",\n  "Data": {}\n}\nEOF\nif [ "$RESPONSE_URL" != "unspecified" ]; then\njq . /tmp/payload.json; curl -fsSL -X PUT -H "Content-Type:" -d "@/tmp/payload.json" "$RESPONSE_URL"\nfi\nfi'
                ],
                finally: failCheckCommands
              }
            }
          }, null, 2)
        }).promise();
        break;
      case "Delete":
        try {
          await s3.deleteObject({
            Bucket: targetBucket,
            Key: event.PhysicalResourceId
          }).promise();
        } catch (e) {
          console.error(`Ignoring error to delete s3://${targetBucket}/${event.PhysicalResourceId}`);
        }
        await customResourceRespond(event, "SUCCESS", "", event.PhysicalResourceId, {});
        break;
    }
  } catch (e) {
    console.error(e);
    await customResourceRespond(event, "FAILED", e.message || "Internal Error", context.logStreamName, {});
  }
}
function logCommands(commands) {
  return [["set -o pipefail ; ( set -ex"].concat(commands).concat([" ) 2>&1 | tee /tmp/codebuild.log"]).join(" ; ")];
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  handler
});
